@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 
 ###############################################################################
@@ -40,6 +40,7 @@ sub new {
     $self->{_val_axis_position} = 'b';
     $self->{_horiz_val_axis}    = 0;
     $self->{_horiz_cat_axis}    = 1;
+    $self->{_show_crosses}      = 0;
 
     bless $self, $class;
 
@@ -56,14 +57,27 @@ sub new {
 sub _write_chart_type {
 
     my $self = shift;
+    my %args = @_;
 
-    # Reverse X and Y axes for Bar charts.
-    my $tmp = $self->{_y_axis};
-    $self->{_y_axis} = $self->{_x_axis};
-    $self->{_x_axis} = $tmp;
+    if ( $args{primary_axes} ) {
+        ## Reverse X and Y axes for Bar charts.
+        my $old_y = $self->{_y_axis};
+        my $old_x = $self->{_x_axis};
+
+        $self->{_y_axis} = $old_x;
+        $self->{_x_axis} = $old_y;
+
+        if ( !$self->{_y_axis}->{_major_gridlines} ) {
+            $self->{_y_axis}->{_major_gridlines} = { show => 1 };
+        }
+
+        if ( $self->{_y2_axis}->{_position} eq 'r' ) {
+            $self->{_y2_axis}->{_position} = 't';
+        }
+    }
 
     # Write the c:barChart element.
-    $self->_write_bar_chart();
+    $self->_write_bar_chart( @_ );
 }
 
 
@@ -76,8 +90,19 @@ sub _write_chart_type {
 sub _write_bar_chart {
 
     my $self = shift;
-    my $subtype = $self->{_subtype};
+    my %args = @_;
 
+    my @series;
+    if ( $args{primary_axes} ) {
+        @series = $self->_get_primary_axes_series;
+    }
+    else {
+        @series = $self->_get_secondary_axes_series;
+    }
+
+    return unless scalar @series;
+
+    my $subtype = $self->{_subtype};
     $subtype = 'percentStacked' if $subtype eq 'percent_stacked';
 
     $self->{_writer}->startTag( 'c:barChart' );
@@ -88,8 +113,17 @@ sub _write_bar_chart {
     # Write the c:grouping element.
     $self->_write_grouping( $subtype );
 
-    # Write the series elements.
-    $self->_write_series();
+    # Write the c:ser elements.
+    $self->_write_ser( $_ ) for @series;
+
+    # Write the c:marker element.
+    $self->_write_marker_value();
+
+    # Write the c:overlap element.
+    $self->_write_overlap() if $self->{_subtype} =~ /stacked/;
+
+    # Write the c:axId elements
+    $self->_write_axis_ids( %args );
 
     $self->{_writer}->endTag( 'c:barChart' );
 }
@@ -112,40 +146,6 @@ sub _write_bar_dir {
 }
 
 
-##############################################################################
-#
-# _write_series()
-#
-# Over-ridden to add c:overlap.
-#
-# Write the series elements.
-#
-sub _write_series {
-
-    my $self = shift;
-
-    # Write each series with subelements.
-    my $index = 0;
-    for my $series ( @{ $self->{_series} } ) {
-        $self->_write_ser( $index++, $series );
-    }
-
-    # Write the c:marker element.
-    $self->_write_marker_value();
-
-    # Write the c:overlap element.
-    $self->_write_overlap() if $self->{_subtype} =~ /stacked/;
-
-    # Generate the axis ids.
-    $self->_add_axis_id();
-    $self->_add_axis_id();
-
-    # Write the c:axId element.
-    $self->_write_axis_id( $self->{_axis_ids}->[0] );
-    $self->_write_axis_id( $self->{_axis_ids}->[1] );
-}
-
-
 ##############################################################################
 #
 # _write_num_fmt()
@@ -161,7 +161,7 @@ sub _write_number_format {
     my $format_code   = shift || 'General';
     my $source_linked = 1;
 
-    if ($self->{_subtype} eq 'percent_stacked') {
+    if ( $self->{_subtype} eq 'percent_stacked' ) {
         $format_code = '0%';
     }
 
