@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 
 ###############################################################################
@@ -53,7 +53,7 @@ sub _write_chart_type {
     my $self = shift;
 
     # Write the c:pieChart element.
-    $self->_write_pie_chart();
+    $self->_write_pie_chart( @_ );
 }
 
 
@@ -61,7 +61,8 @@ sub _write_chart_type {
 #
 # _write_pie_chart()
 #
-# Write the <c:pieChart> element.
+# Write the <c:pieChart> element.  Over-ridden method to remove axis_id code
+# since Pie charts don't require val and cat axes.
 #
 sub _write_pie_chart {
 
@@ -73,9 +74,9 @@ sub _write_pie_chart {
     $self->_write_vary_colors();
 
     # Write the series elements.
-    $self->_write_series();
+    $self->_write_ser( $_ ) for @{ $self->{_series} };
 
-   # Write the c:firstSliceAng element.
+    # Write the c:firstSliceAng element.
     $self->_write_first_slice_ang();
 
     $self->{_writer}->endTag( 'c:pieChart' );
@@ -107,28 +108,6 @@ sub _write_plot_area {
 }
 
 
-##############################################################################
-#
-# _write_series().
-#
-# Over-ridden method to remove axis_id code since Pie charts  don't require
-# val and cat axes.
-#
-# Write the series elements.
-#
-sub _write_series {
-
-    my $self = shift;
-
-    # Write each series with subelements.
-    my $index = 0;
-    for my $series ( @{ $self->{_series} } ) {
-        $self->_write_ser( $index++, $series );
-    }
-}
-
-
-
 ##############################################################################
 #
 # _write_legend().
@@ -139,11 +118,11 @@ sub _write_series {
 #
 sub _write_legend {
 
-    my $self = shift;
+    my $self     = shift;
     my $position = $self->{_legend_position};
-    my $overlay = 0;
+    my $overlay  = 0;
 
-    if ($position =~ s/^overlay_//) {
+    if ( $position =~ s/^overlay_// ) {
         $overlay = 1;
     }
 
@@ -177,7 +156,6 @@ sub _write_legend {
 }
 
 
-
 ##############################################################################
 #
 # _write_tx_pr_legend()
