@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 
 ###############################################################################
@@ -34,6 +34,7 @@ sub new {
 
     my $class = shift;
     my $self  = Excel::Writer::XLSX::Chart->new( @_ );
+    $self->{_show_crosses} = 0;
 
     bless $self, $class;
     return $self;
@@ -51,7 +52,7 @@ sub _write_chart_type {
     my $self = shift;
 
     # Write the c:stockChart element.
-    $self->_write_stock_chart();
+    $self->_write_stock_chart( @_ );
 }
 
 
@@ -60,10 +61,22 @@ sub _write_chart_type {
 # _write_stock_chart()
 #
 # Write the <c:stockChart> element.
+# Overridden to add hi_low_lines(). TODO. Refactor up into the SUPER class.
 #
 sub _write_stock_chart {
 
     my $self = shift;
+    my %args = @_;
+
+    my @series;
+    if ( $args{primary_axes} ) {
+        @series = $self->_get_primary_axes_series;
+    }
+    else {
+        @series = $self->_get_secondary_axes_series;
+    }
+
+    return unless scalar @series;
 
     # Add default formatting to the series data.
     $self->_modify_series_formatting();
@@ -71,51 +84,26 @@ sub _write_stock_chart {
     $self->{_writer}->startTag( 'c:stockChart' );
 
     # Write the series elements.
-    $self->_write_series();
+    $self->_write_ser( $_ ) for @series;
+
+    # Write the c:hiLowLines element.
+    $self->_write_hi_low_lines() if $args{primary_axes};
+
+    # Write the c:marker element.
+    $self->_write_marker_value();
+
+    # Write the c:axId elements
+    $self->_write_axis_ids( %args );
 
     $self->{_writer}->endTag( 'c:stockChart' );
 }
 
 
-##############################################################################
-#
-# _write_series()
-#
-# Over-ridden to add hi_low_lines(). TODO. Refactor up into the SUPER class.
-#
-# Write the series elements.
-#
-sub _write_series {
-
-    my $self = shift;
-
-    # Write each series with subelements.
-    my $index = 0;
-    for my $series ( @{ $self->{_series} } ) {
-        $self->_write_ser( $index++, $series );
-    }
-
-    # Write the c:hiLowLines element.
-    $self->_write_hi_low_lines();
-
-    # Write the c:marker element.
-    $self->_write_marker_value();
-
-    # Generate the axis ids.
-    $self->_add_axis_id();
-    $self->_add_axis_id();
-
-    # Write the c:axId element.
-    $self->_write_axis_id( $self->{_axis_ids}->[0] );
-    $self->_write_axis_id( $self->{_axis_ids}->[1] );
-}
-
-
 ##############################################################################
 #
 # _write_plot_area()
 #
-# Write the <c:plotArea> element.
+# Overridden to use _write_date_axis() instead of _write_cat_axis().
 #
 sub _write_plot_area {
 
@@ -126,14 +114,37 @@ sub _write_plot_area {
     # Write the c:layout element.
     $self->_write_layout();
 
-    # Write the subclass chart type element.
-    $self->_write_chart_type();
+    # TODO: (for JMCNAMARA todo :)
+    # foreach my $chart_type (@chart_types)
 
-    # Write the c:dateAx element.
-    $self->_write_date_axis();
+    # Write the subclass chart type elements for primary and secondary axes
+    $self->_write_chart_type( primary_axes => 1 );
+    $self->_write_chart_type( primary_axes => 0 );
+
+    # Write c:catAx and c:valAx elements for series using primary axes
+    $self->_write_date_axis(
+        x_axis   => $self->{_x_axis},
+        y_axis   => $self->{_y_axis},
+        axis_ids => $self->{_axis_ids}
+    );
+    $self->_write_val_axis(
+        x_axis   => $self->{_x_axis},
+        y_axis   => $self->{_y_axis},
+        axis_ids => $self->{_axis_ids}
+    );
+
+    # Write c:valAx and c:catAx elements for series using secondary axes
+    $self->_write_val_axis(
+        x_axis   => $self->{_x2_axis},
+        y_axis   => $self->{_y2_axis},
+        axis_ids => $self->{_axis2_ids}
+    );
+    $self->_write_date_axis(
+        x_axis   => $self->{_x2_axis},
+        y_axis   => $self->{_y2_axis},
+        axis_ids => $self->{_axis2_ids}
+    );
 
-    # Write the c:catAx element.
-    $self->_write_val_axis();
 
     $self->{_writer}->endTag( 'c:plotArea' );
 }
