@@ -20,7 +20,7 @@ use Exporter;
 use Excel::Writer::XLSX::Worksheet;
 
 our @ISA     = qw(Excel::Writer::XLSX::Worksheet);
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 
 ###############################################################################
@@ -136,6 +136,8 @@ sub protect {
 sub add_series       { return shift->{_chart}->add_series( @_ ) }
 sub set_x_axis       { return shift->{_chart}->set_x_axis( @_ ) }
 sub set_y_axis       { return shift->{_chart}->set_y_axis( @_ ) }
+sub set_x2_axis      { return shift->{_chart}->set_x2_axis( @_ ) }
+sub set_y2_axis      { return shift->{_chart}->set_y2_axis( @_ ) }
 sub set_title        { return shift->{_chart}->set_title( @_ ) }
 sub set_legend       { return shift->{_chart}->set_legend( @_ ) }
 sub set_plotarea     { return shift->{_chart}->set_plotarea( @_ ) }
@@ -152,7 +154,6 @@ sub show_hidden_data { return shift->{_chart}->show_hidden_data( @_ ) }
 ###############################################################################
 
 
-
 ###############################################################################
 #
 # _prepare_chart()
@@ -179,7 +180,6 @@ sub _prepare_chart {
 }
 
 
-
 ###############################################################################
 #
 # XML writing methods.
@@ -187,7 +187,6 @@ sub _prepare_chart {
 ###############################################################################
 
 
-
 ###############################################################################
 #
 # _write_chartsheet()
@@ -214,8 +213,6 @@ sub _write_chartsheet {
 }
 
 
-
-
 ###############################################################################
 #
 # _write_sheet_pr()
